#ifndef QGPCOREWAVE_HEADERS
#define QGPCOREWAVE_HEADERS

// All headers of QGpCoreWave library

#include "ArrivalTime.h"
#include "AutocorrCurves.h"
#include "AutocorrDispersion.h"
#include "AutocorrEngine.h"
#include "AutocorrFactory.h"
#include "AutocorrProxy.h"
#include "AutocorrRing.h"
#include "Dispersion.h"
#include "DispersionFactory.h"
#include "DispersionProxy.h"
#include "Ellipticity.h"
#include "EllipticityFactory.h"
#include "EllipticityProxy.h"
#include "FactoryPoint.h"
#include "FortranInterface.h"
#include "GeophysicalModel.h"
#include "KennettSH.h"
#include "Love.h"
#include "LoveFunction.h"
#include "MagnetoTelluricCurve.h"
#include "MagnetoTelluricFactory.h"
#include "MagnetoTelluricPoint.h"
#include "MagnetoTelluricPointOptions.h"
#include "MagnetoTelluricProxy.h"
#include "ModalCurve.h"
#include "ModalFactory.h"
#include "ModalProxy.h"
#include "ModalRefine.h"
#include "ModalStorage.h"
#include "Mode.h"
#include "OmnidirectionalArrayResponse.h"
#include "Podvin2D.h"
#include "Podvin3D.h"
#include "Profile.h"
#include "QGpCoreWaveDLLExport.h"
#include "RayleighFunction.h"
#include "RefractionCurve.h"
#include "RefractionDippingModel.h"
#include "RefractionFactory.h"
#include "RefractionProxy.h"
#include "Resistivity1DModel.h"
#include "Seismic1DModel.h"
#include "TheoreticalFK.h"
#include "TheoreticalLinearFK.h"
#include "TiltNode.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpCoreWave;
#endif

#endif // QGPCOREWAVE_HEADERS
